@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 2001-2001, William Chia-Wei Cheng.
+ * Copyright (C) 2001-2006, William Chia-Wei Cheng.
  *
  * This file may be distributed under the terms of the Q Public License
  * as defined by Trolltech AS of Norway and appearing in the file
@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/cmdids.h,v 4.66 2002/01/05 02:47:59 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/cmdids.h,v 1.8 2006/06/12 23:46:58 william Exp $
  */
 
 #ifndef _CMDIDS_H_
@@ -362,43 +362,62 @@
 #define CMDID_SETHTMLEXPORTTEMPLATE        422
 #define CMDID_PRINTPAGES                   423
 #define CMDID_GOHYPERSPACEINSLIDESHOW      424
-#define CMDID_FREEHANDMODEINSLIDESHOW      425
-#define CMDID_RECENTLYUSEDFILES            426
-#define CMDID_MOVEEDITTEXTBOX              427
-#define CMDID_GETPROPERTY                  428
-#define CMDID_REPLACEGRAPHIC               429
-#define CMDID_TOGGLESHOWMEASUREMENTINTT    430
-#define CMDID_IMPORTJPEGFILE               431
-#define CMDID_TOGGLEAUTOEPSPREVIEWBITMAP   432
-#define CMDID_CREATETHUMBNAILS             433
-#define CMDID_CONNECT2PORTSBYWIRE          434
-#define CMDID_RENAMESIGNAMEFORAPORT        435
-#define CMDID_CLEARSIGNAMEFORAPORT         436
-#define CMDID_TOGGLESHOWWIRESIGNALNAME     437
-#define CMDID_TOGGLESHOWCHOICEBAR          438
-#define CMDID_MERGEPORTSWITHANOBJECT       439
-#define CMDID_RENUMBER_OBJECT_IDS          440
-#define CMDID_REPEATCONNECT2PORTSBYWIRE    441
-#define CMDID_CONNECTPORTSTOBROADCAST      442
-#define CMDID_IMPORTMULTIPAGETEXTFILE      443
-#define CMDID_SETMARGINSONIMPORTTEXT       444
-#define CMDID_TOGGLEWORDWRAPONIMPORTTEXT   445
-#define CMDID_DATA_IN_MBUFF                446
-#define CMDID_BENCHMARK                    447
-#define CMDID_CONVERTTOBEZIER              448
-#define CMDID_SETBEZIERCONVERTNUMSEGS      449
-#define CMDID_ADDSQUARETICKMARKS           450
-#define CMDID_ADDTRIANGLETICKMARKS         451
-#define CMDID_ADDCIRCLETICKMARKS           452
-#define CMDID_ADDXTICKMARKS                453
-#define CMDID_ADDDIAMONDTICKMARKS          454
-#define CMDID_ADDBOWTIETICKMARKS           455
-#define CMDID_ADDINVTRIANGLETICKMARKS      456
-#define CMDID_ADDPLUSTICKMARKS             457
-#define CMDID_ADDHOURGLASSTICKMARKS        458
-#define CMDID_SETTICKMARKSIZE              459
-#define CMDID_PEEKDIMENSION                460
 
-#define MAXCMDIDS 461
+#define CMDID_FREEHANDMODEINSLIDESHOW    425
+#define CMDID_RECENTLYUSEDFILES          426
+#define CMDID_MOVEEDITTEXTBOX            427
+#define CMDID_GETPROPERTY                428
+#define CMDID_REPLACEGRAPHIC             429
+#define CMDID_TOGGLESHOWMEASUREMENTINTT  430
+#define CMDID_IMPORTJPEGFILE             431
+#define CMDID_TOGGLEAUTOEPSPREVIEWBITMAP 432
+#define CMDID_CREATETHUMBNAILS           433
+#define CMDID_CONNECT2PORTSBYWIRE        434
+#define CMDID_RENAMESIGNAMEFORAPORT      435
+#define CMDID_CLEARSIGNAMEFORAPORT       436
+#define CMDID_TOGGLESHOWWIRESIGNALNAME   437
+#define CMDID_TOGGLESHOWCHOICEBAR        438
+#define CMDID_MERGEPORTSWITHANOBJECT     439
+#define CMDID_RENUMBER_OBJECT_IDS        440
+#define CMDID_REPEATCONNECT2PORTSBYWIRE  441
+#define CMDID_CONNECTPORTSTOBROADCAST    442
+#define CMDID_IMPORTMULTIPAGETEXTFILE    443
+#define CMDID_SETMARGINSONIMPORTTEXT     444
+#define CMDID_TOGGLEWORDWRAPONIMPORTTEXT 445
+#define CMDID_DATA_IN_MBUFF              446
+#define CMDID_BENCHMARK                  447
+#define CMDID_CONVERTTOBEZIER            448
+#define CMDID_SETBEZIERCONVERTNUMSEGS    449
+
+#define CMDID_ADDSQUARETICKMARKS      450
+#define CMDID_ADDTRIANGLETICKMARKS    451
+#define CMDID_ADDCIRCLETICKMARKS      452
+#define CMDID_ADDXTICKMARKS           453
+#define CMDID_ADDDIAMONDTICKMARKS     454
+#define CMDID_ADDBOWTIETICKMARKS      455
+#define CMDID_ADDINVTRIANGLETICKMARKS 456
+#define CMDID_ADDPLUSTICKMARKS        457
+#define CMDID_ADDHOURGLASSTICKMARKS   458
+#define CMDID_SETTICKMARKSIZE         459
+#define CMDID_PEEKDIMENSION           460
+#define CMDID_TOGGLESHOWCHAT          461
+#define CMDID_SAVEPAGESAS             462
+#define CMDID_IMPORTPPMFILE           463
+#define CMDID_ADDPAGEBEFORECOPYALL    464
+#define CMDID_ADDPAGEAFTERCOPYALL     465
+#define CMDID_INSERTHEXOCTALCHAR      466
+#define CMDID_RESETINMETHOD           467
+#define CMDID_IMPORTPBMFILE           468
+#define CMDID_IMPORTPGMFILE           469
+#define CMDID_EDITATTRGROUPINEDITOR   470
+#define CMDID_LINKEXTJPEGFILE         471
+#define CMDID_NEXTSLIDE               472
+#define CMDID_PREVSLIDE               473
+#define CMDID_SETOBJSHADOWCOLOR       474
+#define CMDID_SETOBJSHADOWOFFSETS     475
+#define CMDID_ADDOBJSHADOW            476
+#define CMDID_REMOVEOBJSHADOW         477
+
+#define MAXCMDIDS 478
 
 #endif /*_CMDIDS_H_*/
