@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 2001, William Chia-Wei Cheng.
+ * Copyright (C) 2001-2006, William Chia-Wei Cheng.
  *
  * This file may be distributed under the terms of the Q Public License
  * as defined by Trolltech AS of Norway and appearing in the file
@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/expr.c,v 4.9 2001/08/06 21:39:02 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/expr.c,v 1.3 2006/02/10 23:21:19 william Exp $
  */
 
 #define _INCLUDE_FROM_EXPR_C_
@@ -73,9 +73,11 @@ static char *pszExpr=NULL;
 static struct OpRec *topOpStk=NULL;
 static struct ValRec *topValStk=NULL;
 
+#ifdef NOT_DEFINED
 #ifdef _TGIF_DBG
 static int gnExprDebug=FALSE;
 #endif /* _TGIF_DBG */
+#endif /* NOT_DEFINED */
 
 static
 int BadOperandType(operator_str)
@@ -882,6 +884,7 @@ int ParseForIDVal(ppsz_token, v)
    return TRUE;
 }
 
+#ifdef NOT_DEFINED
 #ifdef _TGIF_DBG /* debug, do not translate */
 static char *opName[] = {
    "BEGIN", "?", ":", "||", "&&", "|", "^", "&", "==", "!=", ">", "<", ">=",
@@ -935,6 +938,7 @@ void DebugValStk()
    fprintf(stderr, "                   |________...\n");
 }
 #endif /* _TGIF_DBG */
+#endif /* NOT_DEFINED */
 
 static
 int ProcessOp(prec)
