@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 2001, William Chia-Wei Cheng.
+ * Copyright (C) 2001-2006, William Chia-Wei Cheng.
  *
  * This file may be distributed under the terms of the Q Public License
  * as defined by Trolltech AS of Norway and appearing in the file
@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/menuinfo.c,v 4.109 2001/10/15 15:23:56 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/menuinfo.c,v 1.9 2006/06/12 23:59:07 william Exp $
  */
 
 #define _INCLUDE_FROM_MENUINFO_C_
@@ -188,6 +188,23 @@ TgMenuInfo stretchableTextModeMenuInfo={ TGMUTYPE_BITMAP,
                                          stretchableTextModeMenuItemInfo,
                                          CreateStretchableTextModeMenu };
 
+static TgMenuItemInfo objShadowMenuItemInfo[] = {
+   { N_("Set Object Shadow Color..."), NULL,
+     N_("Set the shadow color to be used for creating object shadows"), NULL,
+     CMDID_SETOBJSHADOWCOLOR },
+   { N_("Set Object Shadow Offsets..."), NULL,
+     N_("Set the x and y offset for generic object shadow"), NULL,
+     CMDID_SETOBJSHADOWOFFSETS },
+   { N_("Add Object Shadow"), NULL,
+     N_("Add shadows to selected objects"), NULL, CMDID_ADDOBJSHADOW },
+   { N_("Remove Object Shadow"), NULL,
+     N_("Remove shadows from selected objects"), NULL, CMDID_REMOVEOBJSHADOW },
+   { NULL, NULL, NULL, NULL, INVALID }
+};
+static TgMenuInfo objShadowMenuInfo={ TGMUTYPE_TEXT,
+                                      objShadowMenuItemInfo,
+                                      TgCreateMenuFromMenuInfo };
+
 TgMenuInfo shapeMenuInfo={ TGMUTYPE_BITMAP, NULL, CreateShapeMenu };
 
 static TgMenuItemInfo pageLayoutMenuItemInfo[] = {
@@ -268,6 +285,12 @@ static TgMenuItemInfo stackedPageMenuItemInfo[] = {
      NULL, CMDID_ADDPAGEBEFORE },
    { N_("Add Page After..."), NULL,
      N_("Add a page after the current page"), NULL, CMDID_ADDPAGEAFTER },
+   { N_("Add Page Before (Copy All)..."), NULL,
+     N_("Add a page before the current page and copy everything on the current page to the new page"),
+     NULL, CMDID_ADDPAGEBEFORECOPYALL },
+   { N_("Add Page After (Copy All)..."), NULL,
+     N_("Add a page after the current page and copy everything on the current page to the new page"),
+     NULL, CMDID_ADDPAGEAFTERCOPYALL },
    { N_("Delete Current Page"), NULL, N_("Delete the current page"), NULL,
      CMDID_DELETECURPAGE },
    { N_("Delete Pages..."), NULL, N_("Delete user-specified pages"), NULL,
@@ -519,12 +542,21 @@ static TgMenuItemInfo importMenuItemInfo[] = {
      CMDID_IMPORTPNGFILE },
    { N_("Import JPEG File..."), NULL, N_("Embed/Import a JPEG file"), NULL,
      CMDID_IMPORTJPEGFILE },
+   { N_("Import PBM File..."), NULL, N_("Embed/Import a PBM file"), NULL,
+     CMDID_IMPORTPBMFILE },
+   { N_("Import PGM File..."), NULL, N_("Embed/Import a PGM file"), NULL,
+     CMDID_IMPORTPGMFILE },
+   { N_("Import PPM File..."), NULL, N_("Embed/Import a PPM file"), NULL,
+     CMDID_IMPORTPPMFILE },
    { N_("Import Other File..."), NULL, N_("Embed/Import another type of file"),
      NULL, CMDID_IMPORTOTHERFILE },
    { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
    { N_("Embed EPS File..."), NULL, N_("Embed/Import a PS/EPS file"), NULL,
      CMDID_EMBEDEPSFILE },
    { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
+   { N_("Link External JPEG File..."), NULL,
+     N_("Link to an external JPEG file"), NULL, CMDID_LINKEXTJPEGFILE },
+   { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
    { N_("Auto EPS Preview Bitmap"), NULL,
      N_("Auto-generate a preview bitmap for a PS/EPS file when embedding/importing it (if it does not have one already)."), NULL,
      CMDID_TOGGLEAUTOEPSPREVIEWBITMAP },
@@ -614,6 +646,9 @@ static TgMenuItemInfo fileMenuItemInfo[] = {
    { N_("Save Selected As..."), "Alt+~",
      N_("Save selected objects in a different file"), NULL,
      CMDID_SAVESELECTEDAS },
+   { N_("Save Pages As..."), NULL,
+     N_("Save user-specified pages in a different file"), NULL,
+     CMDID_SAVEPAGESAS },
    { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
    { N_("Print"), "Cntrl+p", N_("Print/export current drawing"), NULL,
      CMDID_PRINT },
@@ -815,6 +850,16 @@ static TgMenuItemInfo textMenuItemInfo[] = {
    { N_("Insert Center Subscript"), NULL,
      N_("Insert subscript below the text cursor"), NULL,
      CMDID_INSERTCENTERSUBSCRIPT },
+#ifdef _TGIF_DBG
+   { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
+   { N_("Insert Hex/Octal Character..."), NULL,
+     N_("Insert a character using hex or octal code"), NULL,
+     CMDID_INSERTHEXOCTALCHAR },
+#endif /* _TGIF_DBG */
+   { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
+   { N_("Reset input method..."), NULL,
+     N_("Reset connection to the input method (in case it is stuck)"), NULL,
+     CMDID_RESETINMETHOD },
    { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
    { N_("Insert Thin Space..."), NULL,
      N_("Insert a think space at the text cursor"), NULL,
@@ -886,6 +931,8 @@ static TgMenuItemInfo editMenuItemInfo[] = {
      N_("Select a file and paste the content as text"), NULL,
      CMDID_PASTEFROMFILE },
    { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
+   { N_("Generic Object Shadow"), TGMUITEM_SUBMENU,
+     N_("Generic Object Shadow submenu >>>"), &objShadowMenuInfo, INVALID },
    { N_("Shape"), TGMUITEM_PINNABLESUBMENU,
      N_("Shape submenu >>>"), &shapeMenuInfo, MENU_SHAPE },
    { N_("Set Shape Shadow..."), NULL, N_("Specify the shadow for shapes"), NULL,
@@ -1112,6 +1159,12 @@ static TgMenuItemInfo showHideMenuItemInfo[] = {
      CMDID_TOGGLESHOWCHOICEBAR },
    { N_("Show Status"), NULL, N_("Show status window"), NULL,
      CMDID_TOGGLESHOWSTATUS },
+   { N_("Show Mode"), NULL, N_("Show mode window"), NULL,
+     CMDID_TOGGLESHOWMODE },
+#ifdef _TGIF_WB2
+   { N_("Show Chat"), NULL, N_("Show chat window"), NULL,
+     CMDID_TOGGLESHOWCHAT },
+#endif /* _TGIF_WB2 */
    { NULL, NULL, NULL, NULL, INVALID }
 };
 static TgMenuInfo showHideMenuInfo={ TGMUTYPE_TEXT, showHideMenuItemInfo,
@@ -1125,8 +1178,16 @@ static TgMenuItemInfo slideShowModeMenuItemInfo[] = {
      N_("Go into freehand drawing mode in slideshow"), NULL,
      CMDID_FREEHANDMODEINSLIDESHOW },
    { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
+   { N_("Next Slide"), NULL, N_("Go to next slide"), NULL,
+     CMDID_NEXTPAGE },
+   { N_("Prev Slide"), NULL, N_("Go to previous slide"), NULL,
+     CMDID_PREVPAGE },
+   { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
    { N_("Color"), TGMUITEM_PINNABLESUBMENU,
      N_("Color Menu"), &colorMenuInfo, MENU_COLOR },
+   { TGMUITEM_SEPARATOR, NULL, NULL, NULL, INVALID },
+   { N_("Exit Slide Show Mode"), "Esc", N_("Exit SlideShow mode"), NULL,
+     CMDID_TOGGLESLIDESHOW },
    { NULL, NULL, NULL, NULL, INVALID }
 };
 TgMenuInfo slideShowModeMenuInfo={ TGMUTYPE_TEXT, slideShowModeMenuItemInfo,
@@ -1524,6 +1585,9 @@ TgMenuInfo helpMenuInfo={ TGMUTYPE_TEXT, helpMenuItemInfo,
 TgMenuInfo editAttrInEditorMenuInfo={ TGMUTYPE_TEXT, NULL,
                                       CreateEditAttrInEditorMenu };
 
+TgMenuInfo editAttrGroupInEditorMenuInfo={ TGMUTYPE_TEXT, NULL,
+                                           CreateEditAttrGroupInEditorMenu };
+
 TgMenuInfo getPropertyMenuInfo={ TGMUTYPE_TEXT, NULL, CreateGetPropertyMenu };
 
 TgMenuInfo peekDimensionMenuInfo={ TGMUTYPE_TEXT, NULL,
@@ -1548,6 +1612,9 @@ static TgMenuItemInfo baseContextMenuItemInfo[] = {
    { N_("Edit Attribute In Editor"), TGMUITEM_SUBMENU,
      N_("Edit attribute in editor submenu >>>"), &editAttrInEditorMenuInfo,
      INVALID },
+   { N_("Edit Attribute Group In Editor"), TGMUITEM_SUBMENU,
+     N_("Edit a group of attributes in editor submenu >>>"),
+     &editAttrGroupInEditorMenuInfo, INVALID },
    { N_("Get Property"), TGMUITEM_SUBMENU,
      N_("Get property submenu >>>"), &getPropertyMenuInfo, INVALID },
    { N_("Peek Dimension"), TGMUITEM_SUBMENU,
