@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 2001-2001, William Chia-Wei Cheng.
+ * Copyright (C) 2001-2006, William Chia-Wei Cheng.
  *
  * This file may be distributed under the terms of the Q Public License
  * as defined by Trolltech AS of Norway and appearing in the file
@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/setup.c,v 4.72 2002/03/21 07:44:55 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/setup.c,v 1.20 2006/06/06 00:20:53 william Exp $
  */
 
 #define _INCLUDE_FROM_SETUP_C_
@@ -26,7 +26,7 @@
 
 #include "attr.e"
 #include "auxtext.e"
-/* #include "chat.e" */
+#include "chat.e"
 #include "choice.e"
 #include "choose.e"
 #include "cmd.e"
@@ -75,7 +75,9 @@
 #include "stretch.e"
 #include "strtbl.e"
 #include "tangram2.e"
+#include "tdgtlist.e"
 #include "text.e"
+#include "tidget.e"
 #include "util.e"
 #include "version.e"
 #include "wb.e"
@@ -112,7 +114,8 @@
 #define STATUS_WINDOW_H 20
 #define MODE_WINDOW_W (CHOICE_IMAGE_W)
 #define MODE_WINDOW_H (DRAW_WINDOW_H+RULER_W+(BRDR_W<<1))
-#define CHAT_WINDOW_H (CHOICE_WINDOW_H)
+#define CHAT_WINDOW_W (TITLE_WINDOW_W)
+#define CHAT_WINDOW_H 40
 
 int	debugNoPointerGrab=FALSE;
 
@@ -150,7 +153,7 @@ int	statusSubWindowW[MAX_STATUS_BTNS];
 int	statusSubWindowH[MAX_STATUS_BTNS];
 int	modeWindowW = MODE_WINDOW_W;
 int	modeWindowH = MODE_WINDOW_H;
-int	chatWindowW = STATUS_WINDOW_W;
+int	chatWindowW = CHAT_WINDOW_W;
 int	chatWindowH = CHAT_WINDOW_H;
 
 int	initialMenubarWindowH=MENUBAR_WINDOW_H;
@@ -208,6 +211,8 @@ int	zoomedIn = FALSE;
 struct BBRec	drawWinBBox;
 
 int	colorDisplay = FALSE;
+int	fullTrueColorMode = FALSE;
+int	noAntiAlias = TRUE;
 int	threeDLook = FALSE;
 int	fileModified = FALSE;
 int	objId = 0;
@@ -254,11 +259,17 @@ int	curChoiceBeforeMakeQuiescent=NOTHING;
 
 int	noMinWinSize=TRUE;
 
+int	canvasWindowOnly=FALSE;
+
+int	talkToSelfFiledesInitialized=FALSE;
 int	talkToSelfFiledes[2];
 
-static Atom	protocolAtom=(Atom)0;
+Atom	compoundTextAtom=(Atom)0;
+Atom	textAtom=(Atom)0;
 
-static int	canvasWindowOnly=FALSE;
+static Atom	wmDeleteWindowAtom=(Atom)0;
+static Atom	targetsAtom=(Atom)0;
+static Atom	utf8StringAtom=(Atom)0;
 
 static int	baseScrollBarW=SCROLLBAR_W;
 
@@ -266,7 +277,7 @@ void RegisterWM_DELETE_WINDOW(win)
    Window win;
 {
 #ifndef NOTR4MODE
-   XSetWMProtocols(mainDisplay, win, &protocolAtom, 1);
+   XSetWMProtocols(mainDisplay, win, &wmDeleteWindowAtom, 1);
 #endif
 }
 
@@ -279,7 +290,7 @@ int IsWM_DELETE_WINDOW(pXEvent)
       if (psz == NULL) {
          /* this should not happen, but just in case */
       } else if (strcmp("WM_PROTOCOLS", psz) == 0 &&
-            pXEvent->xclient.data.l[0] == protocolAtom) {
+            pXEvent->xclient.data.l[0] == wmDeleteWindowAtom) {
          XFree((void*)psz);
          return TRUE;
       }
@@ -370,6 +381,7 @@ void InitWinSizes()
          drawWinW+rulerW+brdrW+scrollBarW+(brdrW<<1);
    menubarWindowW = titleWindowW;
    statusWindowW = titleWindowW-userRedrawWindowW-(brdrW<<1);
+   chatWindowW = titleWindowW;
    CalcMenubarWindowHeight();
    msgWindowW = titleWindowW-choiceWindowW-(brdrW<<1);
    mainWinW = titleWindowW+(brdrW<<1);
@@ -380,6 +392,7 @@ void InitWinSizes()
          titleWindowH+vSBarH+scrollBarW+6*brdrW;
    if (colorLayers) vSBarH = DEF_VSBAR_H;
    CalcStatusSubWinGeom();
+   SetChatWindowGeom();
 }
 
 void InverseInitWinSizes()
@@ -387,6 +400,7 @@ void InverseInitWinSizes()
 {
    titleWindowW = mainWinW-(brdrW<<1);
    menubarWindowW = titleWindowW;
+   chatWindowW = titleWindowW;
    statusWindowW = titleWindowW-userRedrawWindowW-(brdrW<<1);
    CalcMenubarWindowHeight();
    msgWindowW = titleWindowW-choiceWindowW-(brdrW<<1);
@@ -404,6 +418,7 @@ void InverseInitWinSizes()
    if (colorLayers) vSBarH = DEF_VSBAR_H;
    CalcMenubarWindowHeight();
    CalcStatusSubWinGeom();
+   SetChatWindowGeom();
 }
 
 void ComputeMainWinXY(MainWinX, MainWinY)
@@ -492,10 +507,6 @@ void DoReconfigure()
    XMoveWindow(mainDisplay, dummyWindow2,
          x_offset+drawWinW+rulerW+(brdrW<<2), cur_y);
    cur_y += scrollBarW + (brdrW<<1);
-   if (!noChatWindow) {
-      XMoveWindow(mainDisplay, chatWindow, 0, cur_y);
-      cur_y += chatWindowH + (brdrW<<1);
-   }
    if (!noStatusWindow) {
       int i;
 
@@ -508,6 +519,11 @@ void DoReconfigure()
                statusSubWindowX[i], statusSubWindowY[i],
                statusSubWindowW[i], statusSubWindowH[i]);
       }
+      cur_y += statusWindowH + (brdrW<<1);
+   }
+   if (!noChatWindow) {
+      MoveResizeChatWindow(0, cur_y, chatWindowW, chatWindowH);
+      cur_y += chatWindowH + (brdrW<<1);
    }
    if (inSlideShow) {
       int dpy_w=DisplayWidth(mainDisplay,mainScreen);
@@ -604,6 +620,8 @@ void Reconfigure(Forced)
             (brdrW*6);
    }
    menubarWindowW = titleWindowW;
+   chatWindowW = titleWindowW;
+   if (!noChatWindow) SetChatWindowGeom();
    statusWindowW = titleWindowW-userRedrawWindowW-(brdrW<<1);
    CalcMenubarWindowHeight();
    msgWindowW = titleWindowW - choiceWindowW - (brdrW<<1);
@@ -640,6 +658,69 @@ int TgIsCmdEvent(pXEv)
    return FALSE;
 }
 
+void HandleSelectionRequest(input)
+   XEvent *input;
+{
+   Window requestor=(Window)0;
+   Atom property=(Atom)0, target=(Atom)0, selection=(Atom)0;
+   XEvent sent_ev;
+
+   requestor = input->xselectionrequest.requestor;
+   selection = input->xselectionrequest.selection;
+   target = input->xselectionrequest.target;
+   property = input->xselectionrequest.property;
+
+#ifdef NOT_DEFINED
+   {
+      static int id=0;
+      char *atom_name=NULL;
+
+      printf("\n%1d: SelectionRequest.\n", ++id);
+
+      atom_name = XGetAtomName(mainDisplay, property);
+      printf("%1d: Property name is '%s'.\n", id, atom_name);
+      XFree(atom_name);
+
+      atom_name = XGetAtomName(mainDisplay, target);
+      printf("%1d: Target name is '%s'.\n", id, atom_name);
+      XFree(atom_name);
+   }
+#endif /* NOT_DEFINED */
+   memset(&sent_ev, 0, sizeof(XEvent));
+
+   sent_ev.xselection.type = SelectionNotify;
+   sent_ev.xselection.display = mainDisplay;
+   sent_ev.xselection.requestor = requestor;
+   sent_ev.xselection.selection = selection;
+   sent_ev.xselection.time = input->xselectionrequest.time;
+   sent_ev.xselection.target = target;
+   sent_ev.xselection.property = None;
+
+   if (target == targetsAtom) {
+      Atom targets[2];
+
+      targets[0] = XA_STRING;
+      targets[1] = compoundTextAtom;
+      targets[2] = textAtom;
+      XChangeProperty(mainDisplay, requestor, property, target, 32,
+            PropModeReplace, (unsigned char *)targets, 3);
+   } else if (target == XA_STRING || target == textAtom) {
+      XChangeProperty(mainDisplay, requestor, property, target, 8,
+            PropModeReplace, (unsigned char *)(dsCutBuffer.s), dsCutBuffer.sz);
+      sent_ev.xselection.property = property;
+   } else if (target == compoundTextAtom) {
+      XTextProperty text_property;
+
+      XmbTextListToTextProperty(mainDisplay, &(dsCutBuffer.s), 1,
+            XCompoundTextStyle, &text_property);
+      XChangeProperty(mainDisplay, requestor, property, target,
+            text_property.format, PropModeReplace, text_property.value,
+            text_property.nitems);
+      sent_ev.xselection.property = property;
+   }
+   XSendEvent(mainDisplay, requestor, False, NoEventMask, &sent_ev);
+}
+
 static XComposeStatus c_stat;
 
 int mainWinEventHandler(input)
@@ -658,16 +739,19 @@ int mainWinEventHandler(input)
       TranslateKeys(s, &key_sym);
 
       if (CharIsESC(key_ev, s, key_sym, &has_ch)) {
-         ToggleSlideShow();
+         LeaveSlideShow();
          return INVALID;
       }
       switch (key_sym) {
-      case XK_Left: PrevPage(); return INVALID;
-      case XK_KP_Left: PrevPage(); return INVALID;
-      case XK_Right: NextPage(); return INVALID;
-      case XK_KP_Right: NextPage(); return INVALID;
+      case XK_Left: PrevSlide(); return INVALID;
+      case XK_KP_Left: PrevSlide(); return INVALID;
+      case XK_Right: NextSlide(); return INVALID;
+      case XK_KP_Right: NextSlide(); return INVALID;
       default: break;
       }
+   } else if (input->type == SelectionRequest) {
+      HandleSelectionRequest(input);
+      return INVALID;
    } else if (input->type == UnmapNotify) {
       Iconify();
    } else if (input->type == MapNotify) {
@@ -707,7 +791,7 @@ int mainWinEventHandler(input)
          } else if (strcmp("WM_MOVED", c_ptr) == 0) {
             configure = TRUE;
          } else if (strcmp("WM_PROTOCOLS", c_ptr) == 0 &&
-               input->xclient.data.l[0] == protocolAtom) {
+               input->xclient.data.l[0] == wmDeleteWindowAtom) {
             XFree((void*)c_ptr);
             return QuitProc();
          } else if (curChoice == DRAWTEXT && canvasFontDoubleByte &&
@@ -852,7 +936,34 @@ void InitTmpDir()
 {
    int tmp_dir_in_x_def=FALSE;
    char *c_ptr=NULL;
+   struct stat stat_buf;
 
+   if ((c_ptr=getenv("HOME")) == NULL) {
+      strcpy(homeDir, DIR_SEP_STR);
+   } else if (strlen(c_ptr) >= MAXPATHLENGTH-1) {
+      strcpy(homeDir, DIR_SEP_STR);
+   } else {
+      strcpy(homeDir, c_ptr);
+   }
+   sprintf(tgifDir, "%s%c.%s", homeDir, DIR_SEP, TOOL_NAME);
+   memset(&stat_buf, 0, sizeof(struct stat));
+   if (stat(tgifDir, &stat_buf) != 0) {
+      /* directory does not exist */
+      if (mkdir(tgifDir, 0755) != 0) {
+         fprintf(stderr, TgLoadString(STID_CANT_CREATE_NAMED_DIRECTORY),
+               tgifDir);
+         fprintf(stderr, "\n");
+         if (!PRTGIF) {
+            fprintf(stderr, "\t");
+            fprintf(stderr, TgLoadString(STID_OPR_USING_NAMED_DIR_WILL_FAIL),
+                  tgifDir);
+            fprintf(stderr, "\n");
+         }
+      }
+   }
+   if (*bootDir == '\0') {
+      GetWorkingDirectory(bootDir, sizeof(bootDir));
+   }
    if (!PRTGIF || cmdLineOpenDisplay) {
       /* do not translate -- program constants */
       if (mainDisplay != NULL &&
@@ -900,6 +1011,30 @@ void InitTmpDir()
    }
 }
 
+static
+int InitAntiAlias()
+   /*
+    * Get here because fullTrueColorMode is TRUE.  So, by default, we
+    *         will use antialiased fonts, unless Tgif.NoAntialias is set
+    *         to TRUE.
+    * Need to add code to talk to the xft server.
+    */
+{
+#ifdef NOT_DEFINED
+   char *c_ptr=NULL;
+
+   noAntiAlias = FALSE;
+   if ((c_ptr=XGetDefault(mainDisplay, TOOL_NAME, "NoAntialias")) !=
+         NULL && UtilStrICmp(c_ptr, "true") == 0) {
+      noAntiAlias = TRUE;
+   }
+#endif /* NOT_DEFINED */
+   /*
+    * Add code here to talk to the xft server.
+    */
+   return TRUE;
+}
+
 void Setup()
 {
    int bitmask=0, x_neg_in_def=FALSE, y_neg_in_def=FALSE;
@@ -907,7 +1042,6 @@ void Setup()
    int bg_pixel=(-1);
    char *c_ptr=NULL;
    int def_x_neg=0, def_y_neg=0, paper_size_set;
-   struct stat stat_buf;
    XWMHints wmhints;
    XSizeHints sizehints;
    XClassHint classhints;
@@ -980,6 +1114,9 @@ void Setup()
          whereToPrint = PNG_FILE;
       } else if (UtilStrICmp(c_ptr, "JPEG") == 0) {
          whereToPrint = JPEG_FILE;
+      } else if (UtilStrICmp(c_ptr, "PPM") == 0 ||
+            UtilStrICmp(c_ptr, "PBM") == 0) {
+         whereToPrint = PPM_FILE;
       } else if (UtilStrICmp(c_ptr, "NetList") == 0) {
          whereToPrint = NETLIST_FILE;
       } else {
@@ -1226,13 +1363,28 @@ void Setup()
          noChoiceWindow = TRUE;
       }
    }
-   noModeWindow = FALSE;
-   if ((c_ptr=XGetDefault(mainDisplay,TOOL_NAME,"NoModeWindow")) != NULL) {
-      if (UtilStrICmp("true", c_ptr) == 0) {
-         noModeWindow = TRUE;
+   if (cmdLineNoModeWindow) {
+      noModeWindow = TRUE;
+   } else {
+      noModeWindow = FALSE;
+      if ((c_ptr=XGetDefault(mainDisplay,TOOL_NAME,"NoModeWindow")) != NULL) {
+         if (UtilStrICmp("true", c_ptr) == 0) {
+            noModeWindow = TRUE;
+         }
       }
    }
-   noChatWindow = TRUE;
+#ifdef _TGIF_WB2
+   if (cmdLineNoChatWindow) {
+      noChatWindow = TRUE;
+   } else {
+      noChatWindow = FALSE;
+      if ((c_ptr=XGetDefault(mainDisplay,TOOL_NAME,"NoChatWindow")) != NULL) {
+         if (UtilStrICmp("true", c_ptr) == 0) {
+            noChatWindow = TRUE;
+         }
+      }
+   }
+#endif /* _TGIF_WB2 */
 
    scrollBarW = baseScrollBarW = SCROLLBAR_W;
    if ((c_ptr=XGetDefault(mainDisplay, TOOL_NAME, "ScrollBarWidth")) != NULL) {
@@ -1254,6 +1406,15 @@ void Setup()
       pageStyle = LANDSCAPE;
       paper_size_set = TRUE;
    }
+   /* do not translate -- program constants */
+   wmDeleteWindowAtom = XInternAtom(mainDisplay, "WM_DELETE_WINDOW", False);
+   targetsAtom = XInternAtom(mainDisplay, "TARGETS", False);
+   utf8StringAtom = XInternAtom(mainDisplay, "UTF8_STRING", False);
+   compoundTextAtom = XInternAtom(mainDisplay, "COMPOUND_TEXT", False);
+   textAtom = XInternAtom(mainDisplay, "TEXT", False);
+   executeCmdByIDAtom = XInternAtom(mainDisplay, "TGIF_EXECUTE_CMD_BY_ID",
+         False);
+
    InitStrTable();
    InitPaperSize();
 
@@ -1357,6 +1518,12 @@ void Setup()
          UtilStrICmp(c_ptr, "false") == 0) {
       stretchableText = FALSE;
    }
+   compoundObjWithTextStretchableForPSE = FALSE;
+   if ((c_ptr=XGetDefault(mainDisplay, TOOL_NAME,
+         "CompoundObjWithTextStretchableForPSE")) != NULL &&
+         UtilStrICmp(c_ptr, "true") == 0) {
+      compoundObjWithTextStretchableForPSE = TRUE;
+   }
    SetEditTextSizeValue(0);
    if ((c_ptr=XGetDefault(mainDisplay, TOOL_NAME, "EditTextSize")) != NULL) {
       int new_edit_text_size=atoi(c_ptr);
@@ -1458,7 +1625,21 @@ void Setup()
 
    colorDisplay = (cmdLineBW || DisplayPlanes(mainDisplay,mainScreen)==1 ||
          mainVisual->class==StaticGray) ? FALSE : TRUE;
-
+   fullTrueColorMode = FALSE;
+   if (colorDisplay && mainVisual->class == TrueColor) {
+#ifdef NOT_DEFINED
+      if ((c_ptr=XGetDefault(mainDisplay, TOOL_NAME, "UseCompatColorScheme")) !=
+            NULL && UtilStrICmp(c_ptr, "true") == 0) {
+         fullTrueColorMode = FALSE;
+      } else {
+         fullTrueColorMode = TRUE;
+      }
+#endif /* NOT_DEFINED */
+   }
+   noAntiAlias = TRUE;
+   if (fullTrueColorMode) {
+      InitAntiAlias();
+   }
    threeDLook = colorDisplay;
    if (threeDLook && (c_ptr=XGetDefault(mainDisplay, TOOL_NAME, "3DLook")) !=
          NULL && UtilStrICmp(c_ptr, "false") == 0) {
@@ -1490,32 +1671,6 @@ void Setup()
    i = strlen(drawPath);
    if (drawPath[i-1] == DIR_SEP) drawPath[i-1] = '\0';
 
-   if ((c_ptr=getenv("HOME")) == NULL) {
-      strcpy(homeDir, DIR_SEP_STR);
-   } else if (strlen(c_ptr) >= MAXPATHLENGTH-1) {
-      strcpy(homeDir, DIR_SEP_STR);
-   } else {
-      strcpy(homeDir, c_ptr);
-   }
-   sprintf(tgifDir, "%s%c.%s", homeDir, DIR_SEP, TOOL_NAME);
-   memset(&stat_buf, 0, sizeof(struct stat));
-   if (stat(tgifDir, &stat_buf) != 0) {
-      /* directory does not exist */
-      if (mkdir(tgifDir, 0755) != 0) {
-         fprintf(stderr, TgLoadString(STID_CANT_CREATE_NAMED_DIRECTORY),
-               tgifDir);
-         fprintf(stderr, "\n");
-         if (!PRTGIF) {
-            fprintf(stderr, "\t");
-            fprintf(stderr, TgLoadString(STID_OPR_USING_NAMED_DIR_WILL_FAIL),
-                  tgifDir);
-            fprintf(stderr, "\n");
-         }
-      }
-   }
-   if (*bootDir == '\0') {
-      GetWorkingDirectory(bootDir, sizeof(bootDir));
-   }
    InitTmpDir();
 
    enableMouseWheel = TRUE;
@@ -1541,11 +1696,12 @@ void Setup()
       statusWindowH += windowPadding;
    }
    userRedrawWindowH = statusWindowH;
-/* chatWindowH = GetChatWindowHeight();
+
+   InitChat();
+   chatWindowH = GetInitialChatWindowHeight();
    if (threeDLook) {
       chatWindowH += windowPadding;
    }
- */
    noMinWinSize = TRUE;
    if (threeDLook && (c_ptr=XGetDefault(mainDisplay, TOOL_NAME,
          "NoMinWinSize")) != NULL && UtilStrICmp(c_ptr, "false") == 0) {
@@ -1669,6 +1825,11 @@ void Setup()
    } else if (!y_in_cmdline && y_neg_in_def) {
       sizehints.y = def_y_neg+DisplayHeight(mainDisplay,mainScreen)-mainWinH-1;
    }
+#if defined(_TANGRAM_II) || defined(_TGIF_WB2)
+   if ( cmdLineParentWindowID > 0 ) {
+      rootWindow = cmdLineParentWindowID;
+   }
+#endif /* defined(_TANGRAM_II) || defined(_TGIF_WB2) */
    if ((mainWindow=XCreateSimpleWindow(mainDisplay, rootWindow,
          sizehints.x, sizehints.y, sizehints.width, sizehints.height,
          brdrW, myBorderPixel, myBgPixel)) == 0) {
@@ -1677,7 +1838,6 @@ void Setup()
    if (newColormapUsed) {
       XSetWindowColormap(mainDisplay, mainWindow, mainColormap);
    }
-   InitWhiteBoard();
    InitMenu();
    InitPattern();
 
@@ -1798,6 +1958,13 @@ void Setup()
          brdrW, myBorderPixel, bg_pixel)) == 0) {
       FailToCreateWindowMessage("Setup()", NULL, TRUE);
    }
+   cur_y += statusWindowH + (brdrW<<1);
+
+   if ((chatWindow=XCreateSimpleWindow(mainDisplay, mainWindow,
+         0, cur_y, chatWindowW, chatWindowH, brdrW, myBorderPixel,
+         bg_pixel)) == 0) {
+      FailToCreateWindowMessage("Setup()", NULL, TRUE);
+   }
    InitScroll();
    CalcStatusSubWinGeom();
    for (i=0; i < MAX_STATUS_BTNS; i++) {
@@ -1808,7 +1975,11 @@ void Setup()
          FailToCreateWindowMessage("Setup()", NULL, TRUE);
       }
    }
+   InitTidget();
    if (!noChatWindow) {
+      if (!CreateChatSubWindows()) {
+         FailToCreateWindowMessage("Setup()", NULL, TRUE);
+      }
       cur_y += chatWindowH + (brdrW<<1);
    }
    if (!noStatusWindow) {
@@ -1831,7 +2002,6 @@ void Setup()
          FailToCreateWindowMessage("Setup()", NULL, TRUE);
       }
    }
-/* CreateChatWindows(); */
 
 #ifdef NOTR4MODE
    XSetNormalHints(mainDisplay, mainWindow, &sizehints);
@@ -1879,6 +2049,7 @@ void Setup()
    InitMeasureTooltip();
    InitPoly();
    InitSpecial();
+   InitAttr();
    InitTalkToSelfFiledes();
 
 #ifdef MAPBEFORESELECT
@@ -1892,10 +2063,6 @@ void Setup()
 #endif
    XDefineCursor(mainDisplay, mainWindow, defaultCursor);
 
-   /* do not translate -- program constants */
-   protocolAtom = XInternAtom(mainDisplay, "WM_DELETE_WINDOW", False);
-   executeCmdByIDAtom = XInternAtom(mainDisplay, "TGIF_EXECUTE_CMD_BY_ID",
-         False);
    RegisterWM_DELETE_WINDOW(mainWindow);
 
 #ifdef MAPBEFORESELECT
@@ -1907,7 +2074,8 @@ void Setup()
             PropertyChangeMask);
    } else {
       XMapWindow(mainDisplay, titleWindow);
-      XSelectInput(mainDisplay, titleWindow, ExposureMask | EnterWindowMask);
+      XSelectInput(mainDisplay, titleWindow,
+            ExposureMask | EnterWindowMask | ButtonPressMask);
 
       if (menubarWindow != None) XMapWindow(mainDisplay, menubarWindow);
       XSelectInput(mainDisplay, menubarWindow, ExposureMask |
@@ -1971,7 +2139,11 @@ void Setup()
 
       if (!noChatWindow) {
          XMapWindow(mainDisplay, chatWindow);
-/*       MapChatSubWindows(); */
+         XSelectInput(mainDisplay, chatWindow,
+               KeyPressMask | ButtonPressMask | ExposureMask |
+               StructureNotifyMask | EnterWindowMask | LeaveWindowMask);
+
+         MapChatSubWindows();
       }
       if (!noStatusWindow) {
          XMapWindow(mainDisplay, userRedrawWindow);
@@ -2001,7 +2173,8 @@ void Setup()
             PropertyChangeMask);
       XMapWindow(mainDisplay, drawWindow); 
    } else {
-      XSelectInput(mainDisplay, titleWindow, ExposureMask | EnterWindowMask);
+      XSelectInput(mainDisplay, titleWindow,
+            ExposureMask | EnterWindowMask | ButtonPressMask);
       XMapWindow(mainDisplay, titleWindow);
 
       XSelectInput(mainDisplay, menubarWindow, ExposureMask |
@@ -2068,7 +2241,10 @@ void Setup()
 
       if (!noChatWindow) {
          XMapWindow(mainDisplay, chatWindow);
-/*       MapChatSubWindows(); */
+         MapChatSubWindows();
+         XSelectInput(mainDisplay, chatWindow,
+               KeyPressMask | ButtonPressMask | ExposureMask |
+               StructureNotifyMask | EnterWindowMask | LeaveWindowMask);
       }
       if (!noStatusWindow) {
          XSelectInput(mainDisplay, userRedrawWindow, ButtonPressMask |
