@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 2001, William Chia-Wei Cheng.
+ * Copyright (C) 2001-2006, William Chia-Wei Cheng.
  *
  * This file may be distributed under the terms of the Q Public License
  * as defined by Trolltech AS of Norway and appearing in the file
@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/stream.c,v 4.19 2001/08/11 21:56:20 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/stream.c,v 1.3 2006/02/10 23:21:21 william Exp $
  */
 
 #define _INCLUDE_FROM_STREAM_C_
@@ -344,7 +344,8 @@ int GetContentLength(buf)
          gnHeaderLen = gnStartIndex = ((&c_ptr[inc]) - buf);
          if (good_content_type && gpszBoundary != NULL) {
             gnMultipartReplace = TRUE;
-            if (debugHttp == 99 && cmdLineDumpURL && cmdLineDumpURLWithHeader) {
+            if ((debugHttp % 100) == 99 && cmdLineDumpURL &&
+                  cmdLineDumpURLWithHeader) {
                fprintf(stdout, "%s", buf);
             }
          } else {
