@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 2001-2003, William Chia-Wei Cheng.
+ * Copyright (C) 2001-2006, William Chia-Wei Cheng.
  *
  * This file may be distributed under the terms of the Q Public License
  * as defined by Trolltech AS of Norway and appearing in the file
@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/tdgtlist.c,v 4.28 2003/08/14 16:40:28 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/tdgtlist.c,v 1.4 2006/02/10 23:21:21 william Exp $
  */
 
 #define _INCLUDE_FROM_TDGTLIST_C_
@@ -28,6 +28,7 @@
 #include "color.e"
 #include "cursor.e"
 #include "dialog.e"
+#include "drawing.e"
 #include "font.e"
 #include "mainloop.e"
 #include "menu.e"
@@ -385,7 +386,7 @@ int DoTdgtListBtnScroll(pTdgtList, scroll_page, scr_dir, pbbox)
    TdgtList *pTdgtList;
    int scroll_page, scr_dir;
    struct BBRec *pbbox;
-   /* returns TRUE if the done scrolling */
+   /* returns TRUE if done scrolling */
 {
    ListInfo *pListInfo=(&pTdgtList->list_info);
    int num_visible_lines=pListInfo->num_visible_lines;
@@ -558,7 +559,7 @@ void TdgtListScrollHandler(pTdgtList, button_ev)
    } else if (button_ev->button == Button1 && button_ev->type == ButtonPress) {
       if (button_ev->y < scrollBarW ||
             button_ev->y >= pTdgtList->scr_area_h-scrollBarW) {
-         int which=0;
+         int which=INVALID;
          struct BBRec bbox;
 
          if (button_ev->y < scrollBarW) {
@@ -602,6 +603,35 @@ void TdgtListScrollHandler(pTdgtList, button_ev)
    }
 }
 
+static
+int TdgtListDspHandler(pTdgtList, button_ev)
+   TdgtList *pTdgtList;
+   XButtonEvent *button_ev;
+{
+   if (enableMouseWheel &&
+         (button_ev->button == Button4 || button_ev->button == Button5)) {
+      int which=INVALID;
+      struct BBRec bbox;
+
+      if (button_ev->button == Button4) {
+         which = SCRL_UP;
+         SetBBRec(&bbox, 0, 0, scrollBarW, scrollBarW);
+      } else if (button_ev->button == Button5) {
+         which = SCRL_DN;
+         SetBBRec(&bbox, 0, pTdgtList->scr_area_h-scrollBarW, scrollBarW,
+               pTdgtList->scr_area_h);
+      }
+      if (which != INVALID) {
+         DoTdgtListBtnScroll(pTdgtList, FALSE, which, &bbox);
+         RedrawTdgtList(pTdgtList->pti);
+      }
+      return INVALID;
+   } else if (button_ev->button != Button1) {
+      return INVALID;
+   }
+   return INVALID;
+}
+
 static
 int TdgtListControlChar(pTdgtList, key_ev, key_sym)
    TdgtList *pTdgtList;
@@ -821,6 +851,11 @@ void ButtonPressInTdgtList(pTdgtList, button_ev, pn_changing,
    if (button_ev->window == pTdgtList->scr_win) {
       TdgtListScrollHandler(pTdgtList, button_ev);
    } else if (button_ev->window == pTdgtList->dsp_win) {
+      int double_clicked=(TdgtListDspHandler(pTdgtList, button_ev)!=INVALID);
+
+      if (double_clicked) {
+         /* do something here */
+      }
       if (pTdgtList->can_select) {
          /* do something here */
       }
