@@ -1,7 +1,7 @@
 /*
  * Author:      William Chia-Wei Cheng (bill.cheng@acm.org)
  *
- * Copyright (C) 2001-2003, William Chia-Wei Cheng.
+ * Copyright (C) 2001-2006, William Chia-Wei Cheng.
  *
  * This file may be distributed under the terms of the Q Public License
  * as defined by Trolltech AS of Norway and appearing in the file
@@ -15,7 +15,7 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION
  * WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/tgif.c,v 4.33 2003/02/25 01:17:49 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/tgif.c,v 1.8 2006/06/09 23:00:00 william Exp $
  */
 
 #define _INCLUDE_FROM_TGIF_C_
@@ -35,6 +35,7 @@
 #include "page.e"
 #include "setup.e"
 #include "strtbl.e"
+#include "tangram2.e"
 #include "util.e"
 #include "version.e"
 
@@ -141,6 +142,9 @@ int PrTgifLoad(FileName)
    FILE *fp=NULL;
    int tmp_linenum=0, gzipped=FALSE;
 
+   if (strcmp(FileName, "-") == 0) {
+      return TRUE;
+   }
    *gzipped_fname = '\0';
    if (FileNameHasExtension(FileName, OBJ_FILE_TYPE, &gzipped, NULL)) {
       if (gzipped) {
@@ -191,7 +195,8 @@ int PrTgifLoad(FileName)
 
    if (!(PRTGIF && cmdLineStdOut)) {
       if (!cmdLineQuiet) {
-         fprintf(stderr, TgLoadCachedString(CSTID_READING_FILE_DOTS), full_name);
+         fprintf(stderr, TgLoadCachedString(CSTID_READING_FILE_DOTS),
+               full_name);
          fprintf(stderr, "\n");
       }
    }
@@ -220,7 +225,7 @@ int PrTgifLoad(FileName)
       unlink(full_name);
       strcpy(full_name, gzipped_fname);
    }
-   if (cmdLineOpenDisplay) {
+   if (cmdLineOpenDisplay || *cmdLineGenParser != '\0') {
       char file_path[MAXPATHLENGTH+1];
 
       if (*full_name == DIR_SEP) {
@@ -264,10 +269,13 @@ void PrTgifDump(inbuf, tile_page_err_msg_id)
    char *inbuf;
    int tile_page_err_msg_id;
 {
-   UtilStrCpyN(cmdLineOpenFile, sizeof(cmdLineOpenFile), inbuf);
+   if (inbuf != NULL && strcmp(inbuf, "-") != 0) {
+      UtilStrCpyN(cmdLineOpenFile, sizeof(cmdLineOpenFile), inbuf);
+   }
+   if (cmdLineNoShowPageInEPS) showPageInEPS = FALSE;
    if (*cmdLineFileToExec != '\0') {
       if (!cmdLineQuiet) {
-         fprintf(stderr, TgLoadCachedString(CSTID_EXECUTING_GIVEN_PROGRAM),
+         fprintf(stderr, TgLoadString(STID_EXECUTING_GIVEN_SCRIPT),
                cmdLineFileToExec);
          fprintf(stderr, "\n");
       }
@@ -284,20 +292,20 @@ void PrTgifDump(inbuf, tile_page_err_msg_id)
             if (cmdLineHasPageNum) {
                sprintf(cmdLinePageNumStr, "%1d", cmdLinePageNum);
                GotoPageNum(cmdLinePageNum);
-               Dump(inbuf);
+               if (inbuf != NULL) Dump(inbuf);
             } else {
                cmdLineHasPageNum = TRUE;
                for (cmdLinePageNum=1; cmdLinePageNum <= lastPageNum;
                      cmdLinePageNum++) {
                   sprintf(cmdLinePageNumStr, "%1d", cmdLinePageNum);
                   GotoPageNum(cmdLinePageNum);
-                  Dump(inbuf);
+                  if (inbuf != NULL) Dump(inbuf);
                }
                cmdLineHasPageNum = FALSE;
             }
          }
       } else {
-         Dump(inbuf);
+         if (inbuf != NULL) Dump(inbuf);
       }
    }
    *cmdLineOpenFile = '\0';
@@ -327,40 +335,66 @@ void DoPrTgif(argc, argv, from_prtgif)
    }
    InitPaperSize();
    InitTmpDir();
-   if (PRTGIF && !cmdLineOpenDisplay) InitDontReencode(NULL);
+   if (PRTGIF && !cmdLineOpenDisplay) {
+      InitDontReencode(NULL);
+      InitPSFontCharSubs();
+   }
+   if (*cmdLineGenParser != '\0') {
+#ifdef _TANGRAM_II
+      InitNames();
+#endif /* _TANGRAM_II */
+   }
    if (argc <= 0) {
       if (cmdLineStdOut) {
          fprintf(stderr, "\n%s\n",
                TgLoadString(STID_SPEC_FILE_WHEN_STDOUT_USED));
          return;
-      }
-      sprintf(gszMsgBox, TgLoadString(STID_TOOL_FILE_NAME_TO_PRINT), TOOL_NAME);
-      fprintf(stderr, "\n%s> ", gszMsgBox);
-      fflush(stderr);
-      while (fgets(inbuf, MAXSTRING, stdin) != NULL) {
-         len = strlen(inbuf);
-         if (len > 0) {
-            if (inbuf[--len] == '\n') inbuf[len] = '\0';
-            if (cmdLineDumpURL) {
-               UrlDump(inbuf);
-            } else if (cmdLineDosEpsFilter) {
-               UtilStrCpyN(cmdLineOpenFile, sizeof(cmdLineOpenFile), inbuf);
-               DosEpsFilter(inbuf);
-            } else {
-               if (cmdLineOpenDisplay) {
-                  JustInit(NULL, NULL);
-               }
-               if (PrTgifLoad(inbuf)) {
-                  PrTgifDump(inbuf, STID_CANT_ONEFPPAGE_IN_TILED_PAGE);
-               } else {
-                  fprintf(stderr, "\n");
-               }
-            }
+      } else if (strcmp(cmdLineFileToExec, "-") == 0) {
+         if (cmdLineOpenDisplay) {
+            JustInit(NULL, NULL);
          }
+         PrTgifDump(NULL, STID_CANT_ONEFPPAGE_IN_TILED_PAGE);
+      } else {
          sprintf(gszMsgBox, TgLoadString(STID_TOOL_FILE_NAME_TO_PRINT),
                TOOL_NAME);
          fprintf(stderr, "\n%s> ", gszMsgBox);
          fflush(stderr);
+         while (fgets(inbuf, MAXSTRING, stdin) != NULL) {
+            len = strlen(inbuf);
+            if (len > 0) {
+               if (inbuf[--len] == '\n') inbuf[len] = '\0';
+               if (*cmdLineGenParser != '\0') {
+#ifdef _TANGRAM_II
+                  if (PrTgifLoad(inbuf)) {
+                     Tangram2GenerateChain(cmdLineGenParser);
+                     DelAllObj();
+                  } else {
+                     fprintf(stderr, "\n");
+                  }
+#endif /* _TANGRAM_II */
+               } else if (cmdLineDumpURL) {
+                  UrlDump(inbuf);
+               } else if (cmdLineDosEpsFilter) {
+                  UtilStrCpyN(cmdLineOpenFile, sizeof(cmdLineOpenFile), inbuf);
+                  DosEpsFilter(inbuf);
+               } else {
+                  if (cmdLineOpenDisplay) {
+                     JustInit(NULL, NULL);
+                  }
+                  if (PrTgifLoad(inbuf)) {
+                     PrTgifDump(inbuf, STID_CANT_ONEFPPAGE_IN_TILED_PAGE);
+                  } else {
+                     fprintf(stderr, "\n");
+                  }
+               }
+            }
+            sprintf(gszMsgBox, TgLoadString(STID_TOOL_FILE_NAME_TO_PRINT),
+                  TOOL_NAME);
+            fprintf(stderr, "\n%s> ", gszMsgBox);
+            fflush(stderr);
+         }
+         fprintf(stderr, "\n");
+         fflush(stderr);
       }
    } else {
       if (cmdLineStdOut && argc > 2) {
@@ -370,7 +404,16 @@ void DoPrTgif(argc, argv, from_prtgif)
       }
       for ( ; argc > 0; argc--, argv++) {
          lastFile = (argc == 1);
-         if (cmdLineDumpURL) {
+         if (*cmdLineGenParser != '\0') {
+#ifdef _TANGRAM_II
+            if (PrTgifLoad(*argv)) {
+               Tangram2GenerateChain(cmdLineGenParser);
+               DelAllObj();
+            } else {
+               fprintf(stderr, "\n");
+            }
+#endif /* _TANGRAM_II */
+         } else if (cmdLineDumpURL) {
             UrlDump(*argv);
             if (argc > 1) {
                fprintf(stderr, "%s\n",
