@@ -1,7 +1,7 @@
 /*
  * Author:      Magnos Martinello, <magnos@land.ufrj.br> in April, 1999.
  *
- * @(#)$Header: /mm/src/tgif/v4/RCS/wb_buff.c,v 4.8 2002/02/28 18:05:36 william Exp $
+ * @(#)$Header: /mm2/home/cvs/bc-src/tgif/wb_buff.c,v 1.1 2004/06/18 23:19:10 william Exp $
  */
 
 /*
@@ -63,7 +63,7 @@ typedef struct {
 
 int MAXTABLE=INITMAXTABLE;  /* Maximum number of active buffers */
 
-header_t **table;
+header_t **table=NULL;
 #ifdef PTHREAD
 pthread_mutex_t table_mp;
 #endif
@@ -144,6 +144,12 @@ const void *))
   return last_used_desc;
 }
 
+void buff_cleanup ()
+{
+  if (table != NULL) free(table);
+  table = NULL;
+}
+
 /***********************************************************************
  * This function inserts a new item in the buffer specified by its     *
  * descriptor. The insertion may be sorted or not, depending on the    *
